# External packages

This directory contains external libraries needed for Marvin. All the libraries included here are develop under licenses that allow for their use and modification provided the source code retains the original copyright. The packages included are:

- [marvin_brain](https://github.com/sdss/marvin_brain/)
- [sdss_access](https://github.com/sdss/sdss_access/)
- [tree](https://github.com/sdss/tree/)
- [SQLAlchemy-boolean-search](https://github.com/sdss/sqlalchemy-boolean-search): fork of [SQLAlchemy-boolean-search](http://sqlalchemy-boolean-search.readthedocs.io/en/latest/) modified for its use with Marvin.
- [WTForms-Alchemy](https://github.com/sdss/wtforms-alchemy): fork of [WTForms-Alchemy](https://wtforms-alchemy.readthedocs.io/en/latest/) modified for its use with Marvin.
- [yanny.py](https://github.com/sdss/marvin/blob/master/python/marvin/extern/yanny.py): a Yanny file reader, modified from the [pydl](https://github.com/weaverba137/pydl) version.
